import { __rest } from 'tslib';
import React from 'react';
import hljs from 'highlight.js';
import cx from 'clsx';
import { useUncontrolled } from '@mantine/hooks';
import { rem, createVarsResolver, factory, useProps, useStyles, UnstyledButton, Box, ScrollArea, Tooltip, ActionIcon, CopyButton } from '@mantine/core';
import { CopyIcon } from './CopyIcon.js';
import { FileIcon } from './FileIcon.js';
import { ExpandIcon } from './ExpandIcon.js';
import _classes from './CodeHighlight.module.css.js';
import themeClasses from './CodeHighlight.theme.module.css.js';

const classes = Object.assign(Object.assign({}, _classes), { root: cx(_classes.root, themeClasses.theme) });
const defaultProps = {
    withHeader: true,
    copyLabel: 'Copy code',
    copiedLabel: 'Copied',
    maxCollapsedHeight: rem('8rem'),
    expandCodeLabel: 'Expand code',
    collapseCodeLabel: 'Collapse code',
};
const varsResolver = createVarsResolver((_, { maxCollapsedHeight }) => ({
    root: { '--ch-max-collapsed-height': rem(maxCollapsedHeight) },
}));
const CodeHighlightTabs = factory((_props, ref) => {
    const props = useProps('CodeHighlightTabs', defaultProps, _props);
    const { classNames, className, style, styles, unstyled, vars, children, code, defaultActiveTab, activeTab, onTabChange, withHeader, copiedLabel, copyLabel, getFileIcon, maxCollapsedHeight, expanded, defaultExpanded, onExpandedChange, expandCodeLabel, collapseCodeLabel, withExpandButton } = props, others = __rest(props, ["classNames", "className", "style", "styles", "unstyled", "vars", "children", "code", "defaultActiveTab", "activeTab", "onTabChange", "withHeader", "copiedLabel", "copyLabel", "getFileIcon", "maxCollapsedHeight", "expanded", "defaultExpanded", "onExpandedChange", "expandCodeLabel", "collapseCodeLabel", "withExpandButton"]);
    const getStyles = useStyles({
        name: 'CodeHighlightTabs',
        props,
        classes,
        className,
        style,
        classNames,
        styles,
        unstyled,
        vars,
        varsResolver,
    });
    const [value, setValue] = useUncontrolled({
        defaultValue: defaultActiveTab,
        value: activeTab,
        finalValue: 0,
        onChange: onTabChange,
    });
    const [_expanded, setExpanded] = useUncontrolled({
        defaultValue: defaultExpanded,
        value: expanded,
        finalValue: true,
        onChange: onExpandedChange,
    });
    const nodes = Array.isArray(code) ? code : [code];
    const currentCode = nodes[value];
    const highlighted = hljs.highlight(currentCode.code.trim(), {
        language: currentCode.language,
    }).value;
    const files = nodes.map((node, index) => (React.createElement(UnstyledButton, Object.assign({}, getStyles('file'), { key: node.fileName, mod: { active: index === value }, onClick: () => setValue(index) }),
        React.createElement(FileIcon, { fileIcon: node.icon, getFileIcon: getFileIcon, fileName: node.fileName }),
        React.createElement("span", null, node.fileName))));
    return (React.createElement(Box, Object.assign({}, getStyles('root'), { ref: ref }, others, { dir: "ltr" }),
        withHeader && (React.createElement("div", Object.assign({}, getStyles('header')),
            React.createElement(ScrollArea, { type: "never", dir: "ltr", offsetScrollbars: false },
                React.createElement("div", Object.assign({}, getStyles('files')), files)),
            React.createElement("div", Object.assign({}, getStyles('controls')),
                withExpandButton && (React.createElement(Tooltip, { label: _expanded ? collapseCodeLabel : expandCodeLabel, fz: "sm", position: "left" },
                    React.createElement(ActionIcon, Object.assign({ onClick: () => setExpanded(!_expanded), variant: "none" }, getStyles('control')),
                        React.createElement(ExpandIcon, { expanded: _expanded })))),
                React.createElement(CopyButton, { value: currentCode.code.trim() }, ({ copied, copy }) => (React.createElement(Tooltip, { label: copied ? copiedLabel : copyLabel, fz: "sm", position: "left" },
                    React.createElement(ActionIcon, Object.assign({ onClick: copy, variant: "none" }, getStyles('control')),
                        React.createElement(CopyIcon, { copied: copied })))))))),
        React.createElement(ScrollArea, { type: "auto", dir: "ltr", offsetScrollbars: false },
            React.createElement(Box, Object.assign({}, getStyles('codeWrapper'), { mod: { expanded: _expanded } }),
                React.createElement("pre", Object.assign({}, getStyles('pre')),
                    React.createElement("code", Object.assign({}, getStyles('code'), { dangerouslySetInnerHTML: { __html: highlighted } }))))),
        React.createElement(UnstyledButton, Object.assign({}, getStyles('showCodeButton'), { mod: { hidden: _expanded }, onClick: () => setExpanded(true) }), "Expand code")));
});
CodeHighlightTabs.displayName = '@mantine/core/CodeHighlightTabs';

export { CodeHighlightTabs };
//# sourceMappingURL=CodeHighlightTabs.js.map
